import { __awaiter, __decorate } from "tslib";
import { NotificationListener } from '@genesislcap/foundation-ui';
import { attr } from '@genesislcap/web-core';
import { customElement, html, ref } from '@microsoft/fast-element';
import * as Notifications from '@openfin/workspace/notifications';
import { IndicatorColor, } from '@openfin/workspace/notifications';
const OpenfinGenesisPriorityMap = {
    Information: 1,
    Warning: 2,
    Serious: 3,
    Critical: 4,
};
const OpenfinGenesisColorMap = {
    Information: IndicatorColor.BLUE,
    Warning: IndicatorColor.YELLOW,
    Serious: IndicatorColor.MAGENTA,
    Critical: IndicatorColor.RED,
};
function initializeNotifications(notificationsPlatformOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        yield Notifications.register({
            notificationsPlatformOptions,
        });
    });
}
/**
 * @tagname openfin-notifications-listener
 * @public
 * @remarks
 * This component extends the notification listener class and overrides the logic for showing the toast message to instead dispatch the event to the openfin notifications bus.
 */
let OpenfinNotificationsListener = class OpenfinNotificationsListener extends NotificationListener {
    constructor() {
        super(...arguments);
        this.toast = 'transient';
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.connectedCallback.call(this);
            yield initializeNotifications(this.notificationsPlatform);
            yield this.addButtonListeners();
        });
    }
    addButtonListeners() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield Notifications.addEventListener('notification-action', (event) => {
                    var _a;
                    console.log(event, 'notification-action button clicked');
                    const button = (_a = this.toastButtons) === null || _a === void 0 ? void 0 : _a.find((t) => t.task === event.result.task);
                    if (!button) {
                        return;
                    }
                    button.action({ details: event.result.customData.details, buttonElement: this });
                });
            }
            catch (e) {
                console.log(e);
            }
        });
    }
    showNotificationToast(row) {
        return __awaiter(this, void 0, void 0, function* () {
            const { HEADER: title, MESSAGE: body, NOTIFY_SEVERITY: type, ALERT_ID } = row;
            const notification = {
                title,
                body,
                priority: OpenfinGenesisPriorityMap[type],
                toast: this.toast || 'transient',
                category: type,
                template: 'markdown',
                id: ALERT_ID,
                soundOptions: {
                    mode: 'silent',
                },
                indicator: {
                    text: title,
                    color: OpenfinGenesisColorMap[type],
                    fallback: OpenfinGenesisColorMap[type],
                },
                buttons: this.mapToastButtons(this.toastButtons, row), // To Do add action buttons
                // platform: PLATFORM_ID
            };
            try {
                yield Notifications.create(notification);
            }
            catch (e) {
                console.error('Openfin notifications error', e);
            }
        });
    }
    mapToastButtons(toastButtons, row) {
        if (!toastButtons) {
            return null;
        }
        return toastButtons
            .filter((t) => !!t.condition({ details: row }))
            .map((t) => {
            return {
                title: t.placeholder,
                type: 'button',
                cta: true,
                onClick: {
                    task: t.task,
                    customData: {
                        message: 'Notification button clicked',
                        details: row,
                    },
                },
            };
        });
    }
};
__decorate([
    attr
], OpenfinNotificationsListener.prototype, "toast", void 0);
OpenfinNotificationsListener = __decorate([
    customElement({
        name: 'openfin-notifications-listener',
        template: html `
    <template ${ref('notificationListener')}>
      <slot></slot>
    </template>
  `,
    })
], OpenfinNotificationsListener);
export { OpenfinNotificationsListener };
